pub struct EOLRequest {
pub subject_id: DigestIdentifier,
}Expand description
A struct representing a request to mark a subject as end-of-life.
Fields
subject_id: DigestIdentifierThe identifier of the subject to mark as end-of-life.